<!-- START BADGE HOOK -->
[![python](https://img.shields.io/badge/python-^3.11.0-blue?logo=python)](https://www.python.org/downloads/release/python-3112/)
<!-- END BADGE HOOK -->

# shield-badger

Generate and inject badges into your README automatically.

**:construction_worker: This project is under construction**

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
<!-- END doctoc generated TOC please keep comment here to allow auto update -->
